#' Add a new article in a fairify project
#'
#' This function prepares an article with a template provided by the **rticles**
#' package.
#'
#' @details
#' This function uses [rmardown::draft] for creating the new document based on
#' a template, so its uses is theoritically not limited to the templates
#' provided by the **rticles** package.
#'
#' @inheritParams add_report
#' @inheritParams rmarkdown::draft
#'
#' @return Used for side effect.
#' @export
#'
#' @examples
add_article <- function(name,
                        template,
                        package = "rticles",
                        path = pkgload::pkg_path(),
                        edit = FALSE) {
  stopifnot(template %in% rticles::journals())

  # reports folder handling
  check_reports_folder(path)

  destpath <- file.path(path, "reports", name)
  if (dir.exists(destpath))
    stop("The folder ",
         destpath,
         " exists already. Delete it first or choose another.")
  dir.create(destpath)

  owd <- setwd(destpath)
  on.exit(setwd(owd))
  rmarkdown::draft("index.Rmd",
                   template = template,
                   package = package,
                   create_dir = FALSE,
                   edit = edit)

  invisible()
}
