#' Set reports folder structure
#'
#' @param path Destination folder for reports and templates
#' @param git add gitignore file suitable for TeX and HTML reports
#'
#' @return The path to the created reports folder.
#' @export
#'
#' @examples
#' # Create structure for reports
#' path <- tempfile(pattern = "report-example")
#' dir.create(path)
#' create_reports(path, git = FALSE)
#' list.files(path, recursive = TRUE)
#'
#' # Add a new report
#' report_path <- add_report("my_report", path = path)
#' list.files(report_path)
create_reports <- function(path = pkgload::pkg_path(), git = TRUE) {
  # Create reports folder
  reports_path <- file.path(path, "reports")
  dir.create(reports_path, showWarnings = FALSE)
  if (git) {
    add_gitignore(
      reports_path,
      url = "https://raw.githubusercontent.com/github/gitignore/main/TeX.gitignore",
      additional_patterns = readLines(pkg_sys("reports_gitignore.txt"))
    )
  }
  invisible(file.path(path, "reports"))
}

check_reports_folder <- function(path) {
  if (!dir.exists(file.path(path, "reports"))) {
    message("Creating reports folder in: ", path, "...")
    create_reports(path)
  }
}
